@@ -1,3 +1,4 @@
+from re import L
 from .lambda_layers import call_lambda_layer
 from .reader import get_graph_as_dict
 import tensorflow as tf
@@ -37,19 +38,27 @@ def replace_layers_by_counterparts_in_model(
                 + "]",
                 end="",
             )
-        layer_input = [
-            network_dict["new_output"][layer_aux]
-            for layer_aux in network_dict["input"][layer.name]
-            if layer_aux != layer.name
-        ]
-        layer_input_shape = None
-        layer_input_shape_custom = False
+        if isinstance(layer, tf.keras.layers.InputLayer):
+            layer_input = network_dict["input"][layer.name]
+        else:
+            input_layers = []
+            for in_node in layer.inbound_nodes:
+                if isinstance(in_node.inbound_layers, (list, tuple)):
+                    for inl in in_node.inbound_layers:
+                        input_layers.append(inl.name)
+                else:
+                    input_layers.append(in_node.inbound_layers.name)
+            layer_input = [
+                network_dict["new_output"][layer_aux] for layer_aux in input_layers
+            ]
         if layer.name in network_dict["new_output"]:
             continue
         if len(layer_input) == 1:
             layer_input = layer_input[0]
 
-        if len(network_dict["input"][layer.name]) == 1:
+        if isinstance(layer, tf.keras.layers.InputLayer):
+            x = layer_input
+        elif len(network_dict["input"][layer.name]) == 1:
             if layer.name in replace_layers_by_provided_counter_parts:
                 modified_layers += 1
                 x = replace_layers_by_provided_counter_parts[layer.name](layer_input)
@@ -64,9 +73,7 @@ def replace_layers_by_counterparts_in_model(
         else:
             if layer.name in replace_layers_by_provided_counter_parts:
                 modified_layers += 1
-                x = replace_layers_by_provided_counter_parts[layer.name](
-                    layer_input[0], layer_input[1]
-                )
+                x = replace_layers_by_provided_counter_parts[layer.name](layer_input)
             elif isinstance(layer, tf.keras.layers.Multiply) or isinstance(
                 layer, tf.keras.layers.Concatenate
             ):
